qmesh3
=======

Note: qmesh3 has been created as a temporary solution to allow qmesh to be installed again using pip to facilitate users access until the original qmesh updates are released.

qmesh is a software package for creating high-quality meshes using `QGIS <https://www.qgis.org>`_ and `Gmsh <https://geuz.org/gmsh>`_.
The meshes can be used in finite element numerical models such as `TELEMAC <http://www.opentelemac.org>`_, `Fluidity <https://www.fluidity-project.org>`_ and `Thetis <https://thetisproject.org/>`_.
For more information please visit the project `website <https://www.qmesh.org>`_.



Development, Maintenance and Licence
------------------------------------

qmesh was developed and is maintained by `Alexandros Avdis <https://orcid.org/0000-0002-2695-3358>`_ and `Jon Hill  <https://orcid.org/0000-0003-1340-4373>`_.
Please see file `AUTHORS.md <https://bitbucket.org/qmesh-developers/qmesh-containers/raw/HEAD/AUTHORS.md>`_ for more information.

qmesh is an open-source project distributed under the GNU General Public Licence v3 (`GPL v3 <https://www.gnu.org/licenses/gpl-3.0.en.html>`_).
The file `LICENCE <https://bitbucket.org/qmesh-developers/qmesh-containers/raw/HEAD/LICENSE>`_ contains a complete copy of the licence.

The source code is freely available to download and adapt, under the conditions stated in the `LICENCE <https://bitbucket.org/qmesh-developers/qmesh-containers/raw/HEAD/LICENSE>`_ file.
However, we follow a closed-development approach, where maintenance and development is carried out by the package originators.
We have opted for this approach to limit the resources needed for development: A larger development team necessitates larger management structures and significant CI/CD expenditure.
Larger management structures will absorb time intended for other exciting and useful research.
CI/CD expenditure could threaten our aim to offer a focused package, at no monetary costs to the users.



Documentation 
---------------

You can access relevant documentation through the following avenues:

* The `qmesh website <https://www.qmesh.org>`_.
* The `qmesh synoptic manual <https://qmesh-synoptic-manual.readthedocs.io/en/latest>`_.
